All Classes and Interfaces

Class
Description
The change root space wrapper for a given FileSystem relocates the paths accessed by an application to the given namespace.
The Class ConcurrentAccessException.
A file (handle) (descriptor) describes a file in a file system.
The mutable FileHandle allows the modification of (fiddling around with) attributes. ------------------------------------------------------------------------- ATTENTION: Usually fiddling around with attributes is not necessary, as the FileSystem itself provides the sufficient functionality to work with files.
Provides an accessor for a file handle property.
Provides a builder method for a file handle property returning the builder for applying multiple build operations.
Provides a mutator for a file handle property.
Provides a file handle property.
Straight forward implementation of the FileHandle,.
Provides an accessor for a size property.
Provides a builder method for a file size property returning the builder for applying multiple build operations.
Provides a mutator for a size property.
Provides a size property.
A file system represents an abstraction for any "physical" storage medium where file (handles) can be stored and retrieved.
Provides an accessor for a FileSystem property.
Provides a mutator for a FileSystem property.
Provides a FileSystem property.
The Class FileSystemUtility.
The Class IllegalFileHandleException.
An in-memory FileSystem using an ConcurrentHashMap for implementation.
The Class NoCreateAccessException.
This exception is thrown when a list (lookup) access was denied.
This exception is thrown whenever a file system to be accessed which does not exist (any more).