Interface FileHandle.MutableFileHandle

All Superinterfaces:
CreatedDateAccessor, CreatedDateAccessor.CreatedDateMutator, CreatedDateAccessor.CreatedDateProperty, FileHandle, FileSizeAccessor, FileSizeAccessor.FileSizeMutator, FileSizeAccessor.FileSizeProperty, ModifiedDateAccessor, ModifiedDateAccessor.ModifiedDateMutator, ModifiedDateAccessor.ModifiedDateProperty, NameAccessor, NameAccessor.NameMutator, NameAccessor.NameProperty, PathAccessor<String>, PathAccessor.PathMutator<String>, PathAccessor.PathProperty<String>
All Known Implementing Classes:
FileHandleImpl.MutableFileHandleImpl
Enclosing interface:
FileHandle

The mutable FileHandle allows the modification of (fiddling around with) attributes. ------------------------------------------------------------------------- ATTENTION: Usually fiddling around with attributes is not necessary, as the FileSystem itself provides the sufficient functionality to work with files. In some cases though this might be necessary: This class is being provided to allow modification of file attributes while making sure that the FileHandle itself creates a copy so that any additional attributes provided by extensions of this interface of whom the developer does not know (yet) are preserved. So extensions of the FileHandle know how to create a FileHandle.MutableFileHandle without information loss, the business logic does not require to take care of any yet unknown extensions. ------------------------------------------------------------------------- CAUTION: Working with modified FileHandles on the FileSystem can aCause unexpected (severe) behavior (data loss), so we assume that you know what you do when using the FileHandle.MutableFileHandle!