Interface FileHandleAccessor
- All Known Subinterfaces:
FileHandleAccessor.FileHandleProperty
- All Known Implementing Classes:
ConcurrentAccessException,FileSystemException.FileException,FileSystemException.NoAccessException,IllegalFileException,NoDeleteAccessException,NoReadAccessException,NoWriteAccessException,UnknownFileException
public interface FileHandleAccessor
Provides an accessor for a file handle property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a file handle property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a file handle property.static interfaceProvides a file handle property. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves the file handle from the file property.
-
Method Details
-
getFileHandle
FileHandle getFileHandle()Retrieves the file handle from the file property.- Returns:
- The file handle stored by the file handle property.
-