Module org.refcodes.filesystem
Package org.refcodes.filesystem
Interface FileHandleAccessor.FileHandleMutator
-
- All Known Subinterfaces:
FileHandleAccessor.FileHandleProperty
- Enclosing interface:
- FileHandleAccessor
public static interface FileHandleAccessor.FileHandleMutatorProvides a mutator for a file handle property.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidsetFile(String aFile)Sets the file handle for the file handle property.
-
-
-
Method Detail
-
setFile
void setFile(String aFile)
Sets the file handle for the file handle property.- Parameters:
aFile- The file handle to be stored by the file handle property.
-
-