Class FileHandleImpl.MutableFileHandleImpl

java.lang.Object
org.refcodes.filesystem.FileHandleImpl
org.refcodes.filesystem.FileHandleImpl.MutableFileHandleImpl
All Implemented Interfaces:
FileHandle, FileHandle.MutableFileHandle, FileSizeAccessor, FileSizeAccessor.FileSizeMutator, FileSizeAccessor.FileSizeProperty, CreatedDateAccessor, CreatedDateAccessor.CreatedDateMutator, CreatedDateAccessor.CreatedDateProperty, ModifiedDateAccessor, ModifiedDateAccessor.ModifiedDateMutator, ModifiedDateAccessor.ModifiedDateProperty, NameAccessor, NameAccessor.NameMutator, NameAccessor.NameProperty, PathAccessor<String>, PathAccessor.PathMutator<String>, PathAccessor.PathProperty<String>
Enclosing class:
FileHandleImpl

public class FileHandleImpl.MutableFileHandleImpl extends FileHandleImpl implements FileHandle.MutableFileHandle
The implementation of a FileHandle.MutableFileHandle. ------------------------------------------------------------------------- CAUTION: fiddling with the path and the name attributes causes the hashCode() and equals(Object) methods to change behavior which can aCause problems ehttps://www.metacodes.proly in collections! ------------------------------------------------------------------------- ATTENTION: In order to avoid the above mentioned problems with the equals(Object) and hashCode() methods, use toFileHandle() before storing a FileHandle.MutableFileHandle in a collection.