-
- All Known Subinterfaces:
FileSystemAccessor.FileSystemProperty
public interface FileSystemAccessorProvides an accessor for aFileSystemproperty.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceFileSystemAccessor.FileSystemMutatorProvides a mutator for aFileSystemproperty.static interfaceFileSystemAccessor.FileSystemPropertyProvides aFileSystemproperty.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description FileSystemgetFileSystem()Gets the file system stored by this property.
-
-
-
Method Detail
-
getFileSystem
FileSystem getFileSystem()
Gets the file system stored by this property.- Returns:
- The file system stored by this property.
-
-