Module org.refcodes.filesystem
Package org.refcodes.filesystem
Class FileSystemAlreadyExistsException
java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.filesystem.FileSystemException
org.refcodes.filesystem.FileSystemAlreadyExistsException
- All Implemented Interfaces:
Serializable,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap
This exception is thrown whenever a file system is to be created though it
already exists. E.g. when using a
ChangeRootFileSystemWrapperImpl and
creating it from scratch for a namespace which already exists.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeProperty -
Constructor Summary
ConstructorsConstructorDescriptionFileSystemAlreadyExistsException(String message) Instantiates a new file system already exists exception.FileSystemAlreadyExistsException(String aMessage, String aErrorCode) Instantiates a new file system already exists exception.FileSystemAlreadyExistsException(String message, Throwable cause) Instantiates a new file system already exists exception.FileSystemAlreadyExistsException(String aMessage, Throwable aCause, String aErrorCode) Instantiates a new file system already exists exception.Instantiates a new file system already exists exception.FileSystemAlreadyExistsException(Throwable aCause, String aErrorCode) Instantiates a new file system already exists exception. -
Method Summary
Methods inherited from class org.refcodes.exception.AbstractException
getErrorCodeMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
Constructor Details
-
FileSystemAlreadyExistsException
Instantiates a new file system already exists exception.- Parameters:
aMessage- the messageaErrorCode- the error code
-
FileSystemAlreadyExistsException
Instantiates a new file system already exists exception.- Parameters:
aMessage- the messageaCause- the causeaErrorCode- the error code
-
FileSystemAlreadyExistsException
Instantiates a new file system already exists exception.- Parameters:
message- the messagecause- the cause
-
FileSystemAlreadyExistsException
Instantiates a new file system already exists exception.- Parameters:
message- the message
-
FileSystemAlreadyExistsException
Instantiates a new file system already exists exception.- Parameters:
aCause- the causeaErrorCode- the error code
-
FileSystemAlreadyExistsException
Instantiates a new file system already exists exception.- Parameters:
cause- the cause
-