Class UnknownFileSystemException

All Implemented Interfaces:
Serializable, ErrorCodeAccessor, Trap

public class UnknownFileSystemException extends FileSystemException
This exception is thrown whenever a file system to be accessed which does not exist (any more). E.g. a namespace was removed or renamed for a ChangeRootFileSystemDecorator.
See Also: