Uses of Interface
org.refcodes.filesystem.FileHandle
-
Uses of FileHandle in org.refcodes.filesystem
Subinterfaces of FileHandle in org.refcodes.filesystemModifier and TypeInterfaceDescriptionstatic interfaceThe mutableFileHandleallows the modification of (fiddling around with) attributes. ------------------------------------------------------------------------- ATTENTION: Usually fiddling around with attributes is not necessary, as theFileSystemitself provides the sufficient functionality to work with files.Classes in org.refcodes.filesystem that implement FileHandleModifier and TypeClassDescriptionclassStraight forward implementation of theFileHandle,.classThe implementation of aFileHandle.MutableFileHandle. ------------------------------------------------------------------------- CAUTION: fiddling with the path and the name attributes causes theFileHandleImpl.MutableFileHandleImpl.hashCode()andFileHandleImpl.MutableFileHandleImpl.equals(Object)methods to change behavior which can aCause problems ehttps://www.metacodes.proly in collections!Fields in org.refcodes.filesystem declared as FileHandleModifier and TypeFieldDescriptionprotected FileHandleFileSystemException.FileException._fileHandleMethods in org.refcodes.filesystem that return FileHandleModifier and TypeMethodDescriptionChangeRootFileSystemDecorator.createFile(String aKey) Creates a file (handle) with the given key.ChangeRootFileSystemDecorator.createFile(String aPath, String aName) Creates a file (handle) with the given path and name.FileSystem.createFile(String aKey) Creates a file (handle) with the given key.FileSystem.createFile(String aPath, String aName) Creates a file (handle) with the given path and name.InMemoryFileSystem.createFile(String aKey) Creates a file (handle) with the given key.InMemoryFileSystem.createFile(String aPath, String aName) Creates a file (handle) with the given path and name.ChangeRootFileSystemDecorator.getFileHandle(String aKey) Gets a file (handle) with the given key from the file system.ChangeRootFileSystemDecorator.getFileHandle(String aPath, String aName) Gets a file (handle) with the given path and name from the file system.FileHandleAccessor.getFileHandle()Retrieves the file handle from the file property.FileSystem.getFileHandle(String aKey) Gets a file (handle) with the given key from the file system.FileSystem.getFileHandle(String aPath, String aName) Gets a file (handle) with the given path and name from the file system.FileSystemException.FileException.getFileHandle()Retrieves the file handle from the file property.InMemoryFileSystem.getFileHandle(String aKey) Gets a file (handle) with the given key from the file system.InMemoryFileSystem.getFileHandle(String aPath, String aName) Gets a file (handle) with the given path and name from the file system.default FileHandleFileHandleAccessor.FileHandleProperty.letFileHandle(String aHandle) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given file handle (setter) as ofFileHandleAccessor.FileHandleMutator.setFileHandle(String)and returns the very same value (getter) being produced to aFileHandle(as ofFileHandleAccessor.getFileHandle()).ChangeRootFileSystemDecorator.moveFile(FileHandle aFileHandle, String aNewKey) Renames the file (handle), it will be accessible via the provided key.FileSystem.moveFile(FileHandle aFileHandle, String aNewKey) Renames the file (handle), it will be accessible via the provided key.InMemoryFileSystem.moveFile(FileHandle aFileHandle, String aNewKey) Renames the file (handle), it will be accessible via the provided key.ChangeRootFileSystemDecorator.renameFile(FileHandle aFileHandle, String aNewName) Renames the file (handle), the name part of the key will be renamed to the new name.FileSystem.renameFile(FileHandle aFileHandle, String aNewName) Renames the file (handle), the name part of the key will be renamed to the new name.InMemoryFileSystem.renameFile(FileHandle aFileHandle, String aNewName) Renames the file (handle), the name part of the key will be renamed to the new name.FileHandle.MutableFileHandle.toFileHandle()Converts theFileHandle.MutableFileHandleback to aFileHandleto avoid hassle with collections, theObject.hashCode()and theObject.equals(Object)operations.FileHandleImpl.MutableFileHandleImpl.toFileHandle()Converts theFileHandle.MutableFileHandleback to aFileHandleto avoid hassle with collections, theObject.hashCode()and theObject.equals(Object)operations.static FileHandleFileSystemUtility.toNormalizedFileHandle(FileHandle aFileHandle, FileSystem aFileSystem) Test whether the given key may jail break from the name space.Methods in org.refcodes.filesystem that return types with arguments of type FileHandleModifier and TypeMethodDescriptionChangeRootFileSystemDecorator.getFileHandles(String aPath, boolean isRecursively) With the behavior of theFileSystem.hasFiles(String, boolean)method, all file (handle)s found for the path are returned.FileSystem.getFileHandles(String aPath, boolean isRecursively) With the behavior of theFileSystem.hasFiles(String, boolean)method, all file (handle)s found for the path are returned.InMemoryFileSystem.getFileHandles(String aPath, boolean isRecursively) With the behavior of theFileSystem.hasFiles(String, boolean)method, all file (handle)s found for the path are returned.Methods in org.refcodes.filesystem with parameters of type FileHandleModifier and TypeMethodDescriptionvoidChangeRootFileSystemDecorator.deleteFile(FileHandle aFileHandle) Deletes a file (handle) from the file system.voidFileSystem.deleteFile(FileHandle aFileHandle) Deletes a file (handle) from the file system.voidInMemoryFileSystem.deleteFile(FileHandle aFileHandle) Deletes a file (handle) from the file system.ChangeRootFileSystemDecorator.fromFile(FileHandle aFromFileHandle) An input stream is being provided from which the data of the file (handle) may be read.voidChangeRootFileSystemDecorator.fromFile(FileHandle aFromFileHandle, File aToFile) The data contained in the given file (handle) is written to the provided file.voidChangeRootFileSystemDecorator.fromFile(FileHandle aFromFileHandle, OutputStream aOutputStream) The data contained in the given file (handle) is written to the provided output stream.FileSystem.fromFile(FileHandle aFromFileHandle) An input stream is being provided from which the data of the file (handle) may be read.voidFileSystem.fromFile(FileHandle aFromFileHandle, File aToFile) The data contained in the given file (handle) is written to the provided file.voidFileSystem.fromFile(FileHandle aFromFileHandle, OutputStream aOutputStream) The data contained in the given file (handle) is written to the provided output stream.InMemoryFileSystem.fromFile(FileHandle aFromFileHandle) An input stream is being provided from which the data of the file (handle) may be read.voidInMemoryFileSystem.fromFile(FileHandle aFromFileHandle, File aToFile) The data contained in the given file (handle) is written to the provided file.voidInMemoryFileSystem.fromFile(FileHandle aFromFileHandle, OutputStream aOutputStream) The data contained in the given file (handle) is written to the provided output stream.booleanChangeRootFileSystemDecorator.hasFile(FileHandle aFileHandle) Returns true in case the given file (handle) exists.booleanFileSystem.hasFile(FileHandle aFileHandle) Returns true in case the given file (handle) exists.booleanInMemoryFileSystem.hasFile(FileHandle aFileHandle) Returns true in case the given file (handle) exists.ChangeRootFileSystemDecorator.moveFile(FileHandle aFileHandle, String aNewKey) Renames the file (handle), it will be accessible via the provided key.FileSystem.moveFile(FileHandle aFileHandle, String aNewKey) Renames the file (handle), it will be accessible via the provided key.InMemoryFileSystem.moveFile(FileHandle aFileHandle, String aNewKey) Renames the file (handle), it will be accessible via the provided key.ChangeRootFileSystemDecorator.renameFile(FileHandle aFileHandle, String aNewName) Renames the file (handle), the name part of the key will be renamed to the new name.FileSystem.renameFile(FileHandle aFileHandle, String aNewName) Renames the file (handle), the name part of the key will be renamed to the new name.InMemoryFileSystem.renameFile(FileHandle aFileHandle, String aNewName) Renames the file (handle), the name part of the key will be renamed to the new name.ChangeRootFileSystemDecorator.toFile(FileHandle aToFileHandle) Returns an output stream which may be used to write (or append, in case data did already exist for the file system) data to a file (handle).voidChangeRootFileSystemDecorator.toFile(FileHandle aToFileHandle, byte[] aBuffer) Data provided by the given buffer is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).voidChangeRootFileSystemDecorator.toFile(FileHandle aToFileHandle, File aFromFile) Data provided by the given input stream is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).voidChangeRootFileSystemDecorator.toFile(FileHandle aToFileHandle, InputStream aInputStream) Data provided by the given input stream is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).FileSystem.toFile(FileHandle aToFileHandle) Returns an output stream which may be used to write (or append, in case data did already exist for the file system) data to a file (handle).voidFileSystem.toFile(FileHandle aToFileHandle, byte[] aBuffer) Data provided by the given buffer is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).voidFileSystem.toFile(FileHandle aToFileHandle, File aFromFile) Data provided by the given input stream is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).voidFileSystem.toFile(FileHandle aToFileHandle, InputStream aInputStream) Data provided by the given input stream is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).InMemoryFileSystem.toFile(FileHandle aToFileHandle) Returns an output stream which may be used to write (or append, in case data did already exist for the file system) data to a file (handle).voidInMemoryFileSystem.toFile(FileHandle aToFileHandle, byte[] aBuffer) Data provided by the given buffer is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).voidInMemoryFileSystem.toFile(FileHandle aToFileHandle, File aFromFile) Data provided by the given input stream is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).voidInMemoryFileSystem.toFile(FileHandle aToFileHandle, InputStream aInputStream) Data provided by the given input stream is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).static FileHandleFileSystemUtility.toNormalizedFileHandle(FileHandle aFileHandle, FileSystem aFileSystem) Test whether the given key may jail break from the name space.Constructors in org.refcodes.filesystem with parameters of type FileHandleModifierConstructorDescriptionConcurrentAccessException(String aMessage, FileHandle aFileHandle) ConcurrentAccessException(String aMessage, FileHandle aFileHandle, String aErrorCode) ConcurrentAccessException(String aMessage, FileHandle aFileHandle, Throwable aCause) ConcurrentAccessException(String aMessage, FileHandle aFileHandle, Throwable aCause, String aErrorCode) ConcurrentAccessException(FileHandle aFileHandle, Throwable aCause) ConcurrentAccessException(FileHandle aFileHandle, Throwable aCause, String aErrorCode) FileException(FileHandle aFileHandle, String aMessage) FileException(FileHandle aFileHandle, String aMessage, String aErrorCode) FileException(FileHandle aFileHandle, String aMessage, Throwable aCause) FileException(FileHandle aFileHandle, String aMessage, Throwable aCause, String aErrorCode) FileException(FileHandle aFileHandle, Throwable aCause) FileException(FileHandle aFileHandle, Throwable aCause, String aErrorCode) FileHandleImpl(FileHandle aFileHandle) Constructs aFileHandleobject with the properties of the givenFileHandle.IllegalFileException(FileHandle aFile, String aMessage) IllegalFileException(FileHandle aFile, String aMessage, String aErrorCode) IllegalFileException(FileHandle aFile, String aMessage, Throwable aCause) IllegalFileException(FileHandle aFile, String aMessage, Throwable aCause, String aErrorCode) IllegalFileException(FileHandle aFile, Throwable aCause) IllegalFileException(FileHandle aFile, Throwable aCause, String aErrorCode) MutableFileHandleImpl(FileHandle aFileHandle) Instantiates a new mutable file handle impl.NoAccessException(FileHandle aFileHandle, String aMessage) NoAccessException(FileHandle aFileHandle, String aMessage, String aErrorCode) NoAccessException(FileHandle aFileHandle, String aMessage, Throwable aCause) NoAccessException(FileHandle aFileHandle, String aMessage, Throwable aCause, String aErrorCode) NoAccessException(FileHandle aFileHandle, Throwable aCause) NoAccessException(FileHandle aFileHandle, Throwable aCause, String aErrorCode) NoDeleteAccessException(String aMessage, FileHandle aFileHandle) NoDeleteAccessException(String aMessage, FileHandle aFileHandle, String aErrorCode) NoDeleteAccessException(String aMessage, FileHandle aFileHandle, Throwable aCause) NoDeleteAccessException(String aMessage, FileHandle aFileHandle, Throwable aCause, String aErrorCode) NoDeleteAccessException(FileHandle aFileHandle, Throwable aCause) NoDeleteAccessException(FileHandle aFileHandle, Throwable aCause, String aErrorCode) NoReadAccessException(FileHandle aFileHandle, String aMessage) NoReadAccessException(FileHandle aFileHandle, String aMessage, String aErrorCode) NoReadAccessException(FileHandle aFileHandle, String aMessage, Throwable aCause) NoReadAccessException(FileHandle aFileHandle, String aMessage, Throwable aCause, String aErrorCode) NoReadAccessException(FileHandle aFileHandle, Throwable aCause) NoReadAccessException(FileHandle aFileHandle, Throwable aCause, String aErrorCode) NoWriteAccessException(FileHandle aFileHandle, String aMessage) NoWriteAccessException(FileHandle aFileHandle, String aMessage, String aErrorCode) NoWriteAccessException(FileHandle aFileHandle, String aMessage, Throwable aCause) NoWriteAccessException(FileHandle aFileHandle, String aMessage, Throwable aCause, String aErrorCode) NoWriteAccessException(FileHandle aFileHandle, Throwable aCause) NoWriteAccessException(FileHandle aFileHandle, Throwable aCause, String aErrorCode) UnknownFileException(FileHandle aFileHandle, String aMessage) UnknownFileException(FileHandle aFileHandle, String aMessage, String aErrorCode) UnknownFileException(FileHandle aFileHandle, String aMessage, Throwable aCause) UnknownFileException(FileHandle aFileHandle, String aMessage, Throwable aCause, String aErrorCode) UnknownFileException(FileHandle aFileHandle, Throwable aCause) UnknownFileException(FileHandle aFileHandle, Throwable aCause, String aErrorCode)