Uses of Interface
org.refcodes.filesystem.FileHandle.MutableFileHandle
-
-
Uses of FileHandle.MutableFileHandle in org.refcodes.filesystem
Classes in org.refcodes.filesystem that implement FileHandle.MutableFileHandle Modifier and Type Class Description classFileHandleImpl.MutableFileHandleImplThe implementation of aFileHandle.MutableFileHandle. ------------------------------------------------------------------------- CAUTION: fiddling with the path and the name attributes causes theFileHandleImpl.MutableFileHandleImpl.hashCode()andFileHandleImpl.MutableFileHandleImpl.equals(Object)methods to change behavior which can cause problems especially in collections!Methods in org.refcodes.filesystem that return FileHandle.MutableFileHandle Modifier and Type Method Description FileHandle.MutableFileHandleFileHandle. toMutableFileHandle()Converts the giveFileHandleto aFileHandle.MutableFileHandle.FileHandle.MutableFileHandleFileHandleImpl. toMutableFileHandle()Converts the giveFileHandleto aFileHandle.MutableFileHandle.
-