Uses of Class
org.refcodes.filesystem.FileHandleImpl
-
-
Uses of FileHandleImpl in org.refcodes.filesystem
Subclasses of FileHandleImpl in org.refcodes.filesystem Modifier and Type Class Description classFileHandleImpl.MutableFileHandleImplThe implementation of aFileHandle.MutableFileHandle. ------------------------------------------------------------------------- CAUTION: fiddling with the path and the name attributes causes theFileHandleImpl.MutableFileHandleImpl.hashCode()andFileHandleImpl.MutableFileHandleImpl.equals(Object)methods to change behavior which can cause problems especially in collections!
-