Uses of Interface
org.refcodes.filesystem.FileSystem
-
Uses of FileSystem in org.refcodes.filesystem
Classes in org.refcodes.filesystem that implement FileSystemModifier and TypeClassDescriptionclassThe change root space wrapper for a givenFileSystemrelocates the paths accessed by an application to the given namespace.classAn in-memoryFileSystemusing anConcurrentHashMapfor implementation.Methods in org.refcodes.filesystem that return FileSystemModifier and TypeMethodDescriptionFileSystemAccessor.getFileSystem()Gets the file system stored by this property.default FileSystemFileSystemAccessor.FileSystemProperty.letFileSystem(FileSystem aFileSystem) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenFileSystem(setter) as ofFileSystemAccessor.FileSystemMutator.setFileSystem(FileSystem)and returns the very same value (getter).Methods in org.refcodes.filesystem with parameters of type FileSystemModifier and TypeMethodDescriptionstatic voidFileSystemUtility.deleteFiles(FileSystem aFileSystem, String aPath, boolean isRecursively) Deletes the entries found for the given path.default FileSystemFileSystemAccessor.FileSystemProperty.letFileSystem(FileSystem aFileSystem) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenFileSystem(setter) as ofFileSystemAccessor.FileSystemMutator.setFileSystem(FileSystem)and returns the very same value (getter).voidFileSystemAccessor.FileSystemMutator.setFileSystem(FileSystem aFileSystem) Sets the file system for this property.static FileHandleFileSystemUtility.toNormalizedFileHandle(FileHandle aFileHandle, FileSystem aFileSystem) Test whether the given key may jail break from the name space.static StringFileSystemUtility.toNormalizedKey(String aKey, FileSystem aFileSystem) Truncates any prefixed path separator as we assemble our new path with the according namespace in front.static StringFileSystemUtility.toNormalizedName(String aName, FileSystem aFileSystem) Truncates any prefixed path separator as we assemble our new path with the according namespace in front.static StringFileSystemUtility.toNormalizedPath(String aPath, FileSystem aFileSystem) Truncates any prefixed path separator as we assemble our new path with the according namespace in front.Constructors in org.refcodes.filesystem with parameters of type FileSystemModifierConstructorDescriptionChangeRootFileSystemDecorator(String aNamespace, FileSystem aFileSystem) Instantiates a new change root file system wrapper impl.