Uses of Class
org.refcodes.filesystem.NoReadAccessException
-
Uses of NoReadAccessException in org.refcodes.filesystem
Methods in org.refcodes.filesystem that throw NoReadAccessExceptionModifier and TypeMethodDescriptionChangeRootFileSystemDecorator.fromFile(FileHandle aFromFileHandle) An input stream is being provided from which the data of the file (handle) may be read.voidChangeRootFileSystemDecorator.fromFile(FileHandle aFromFileHandle, File aToFile) The data contained in the given file (handle) is written to the provided file.voidChangeRootFileSystemDecorator.fromFile(FileHandle aFromFileHandle, OutputStream aOutputStream) The data contained in the given file (handle) is written to the provided output stream.FileSystem.fromFile(FileHandle aFromFileHandle) An input stream is being provided from which the data of the file (handle) may be read.voidFileSystem.fromFile(FileHandle aFromFileHandle, File aToFile) The data contained in the given file (handle) is written to the provided file.voidFileSystem.fromFile(FileHandle aFromFileHandle, OutputStream aOutputStream) The data contained in the given file (handle) is written to the provided output stream.InMemoryFileSystem.fromFile(FileHandle aFromFileHandle) An input stream is being provided from which the data of the file (handle) may be read.voidInMemoryFileSystem.fromFile(FileHandle aFromFileHandle, File aToFile) The data contained in the given file (handle) is written to the provided file.voidInMemoryFileSystem.fromFile(FileHandle aFromFileHandle, OutputStream aOutputStream) The data contained in the given file (handle) is written to the provided output stream.