Uses of Class
org.refcodes.filesystem.NoWriteAccessException

  • Uses of NoWriteAccessException in org.refcodes.filesystem

    Modifier and Type
    Method
    Description
    ChangeRootFileSystemDecorator.toFile(FileHandle aToFileHandle)
    Returns an output stream which may be used to write (or append, in case data did already exist for the file system) data to a file (handle).
    void
    ChangeRootFileSystemDecorator.toFile(FileHandle aToFileHandle, byte[] aBuffer)
    Data provided by the given buffer is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).
    void
    ChangeRootFileSystemDecorator.toFile(FileHandle aToFileHandle, File aFromFile)
    Data provided by the given input stream is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).
    void
    ChangeRootFileSystemDecorator.toFile(FileHandle aToFileHandle, InputStream aInputStream)
    Data provided by the given input stream is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).
    FileSystem.toFile(FileHandle aToFileHandle)
    Returns an output stream which may be used to write (or append, in case data did already exist for the file system) data to a file (handle).
    void
    FileSystem.toFile(FileHandle aToFileHandle, byte[] aBuffer)
    Data provided by the given buffer is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).
    void
    FileSystem.toFile(FileHandle aToFileHandle, File aFromFile)
    Data provided by the given input stream is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).
    void
    FileSystem.toFile(FileHandle aToFileHandle, InputStream aInputStream)
    Data provided by the given input stream is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).
    InMemoryFileSystem.toFile(FileHandle aToFileHandle)
    Returns an output stream which may be used to write (or append, in case data did already exist for the file system) data to a file (handle).
    void
    InMemoryFileSystem.toFile(FileHandle aToFileHandle, byte[] aBuffer)
    Data provided by the given buffer is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).
    void
    InMemoryFileSystem.toFile(FileHandle aToFileHandle, File aFromFile)
    Data provided by the given input stream is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).
    void
    InMemoryFileSystem.toFile(FileHandle aToFileHandle, InputStream aInputStream)
    Data provided by the given input stream is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).