Uses of Class
org.refcodes.filesystem.UnknownKeyException
-
Uses of UnknownKeyException in org.refcodes.filesystem
Methods in org.refcodes.filesystem that throw UnknownKeyExceptionModifier and TypeMethodDescriptionChangeRootFileSystemDecorator.getFileHandle(String aKey) Gets a file (handle) with the given key from the file system.ChangeRootFileSystemDecorator.getFileHandle(String aPath, String aName) Gets a file (handle) with the given path and name from the file system.FileSystem.getFileHandle(String aKey) Gets a file (handle) with the given key from the file system.FileSystem.getFileHandle(String aPath, String aName) Gets a file (handle) with the given path and name from the file system.InMemoryFileSystem.getFileHandle(String aKey) Gets a file (handle) with the given key from the file system.InMemoryFileSystem.getFileHandle(String aPath, String aName) Gets a file (handle) with the given path and name from the file system.