public static interface FileHandle.MutableFileHandle extends FileHandle, org.refcodes.mixin.mixins.PathAccessor.PathProperty, org.refcodes.mixin.mixins.NameAccessor.NameProperty, org.refcodes.mixin.mixins.SizeAccessor.SizeProperty, org.refcodes.mixin.mixins.CreatedDateAccessor.CreatedDateProperty, org.refcodes.mixin.mixins.ModifiedDateAccessor.ModifiedDateProperty
FileHandle allows the modification of (fiddling
around with) attributes.
-------------------------------------------------------------------------
ATTENTION: Usually fiddling around with attributes is not necessary, as
the FileSystem itself provides the sufficient functionality to
work with files. In some cases though this might be necessary: This class
is being provided to allow modification of file attributes while making
sure that the FileHandle itself creates a copy so that any
additional attributes provided by extensions of this interface of whom
the developer does not know (yet) are preserved. So extensions of the
FileHandle know how to create a FileHandle.MutableFileHandle without
information loss, the business logic does not require to take care of any
yet unknown extensions.
-------------------------------------------------------------------------
CAUTION: Working with modified FileHandles on the
FileSystem can cause unexpected (severe) behavior (data loss), so
we assume that you know what you do when using the
FileHandle.MutableFileHandle!FileHandle.MutableFileHandleorg.refcodes.mixin.mixins.PathAccessor.PathMutator, org.refcodes.mixin.mixins.PathAccessor.PathPropertyorg.refcodes.mixin.mixins.NameAccessor.NameBuilder<B>, org.refcodes.mixin.mixins.NameAccessor.NameMutator, org.refcodes.mixin.mixins.NameAccessor.NamePropertyorg.refcodes.mixin.mixins.SizeAccessor.SizeMutator, org.refcodes.mixin.mixins.SizeAccessor.SizeProperty| Modifier and Type | Method and Description |
|---|---|
FileHandle |
toFileHandle()
Converts the
FileHandle.MutableFileHandle back to a FileHandle
to avoid hassle with collections, the #hashCode() and the
#equals(Object) operations. |
getCreatedDate, getModifiedDate, getName, getPath, getSize, toKey, toMutableFileHandleFileHandle toFileHandle()
FileHandle.MutableFileHandle back to a FileHandle
to avoid hassle with collections, the #hashCode() and the
#equals(Object) operations.FileHandle from this
FileHandle.MutableFileHandle.Copyright © 2015. All rights reserved.