Uses of Interface
org.refcodes.filesystem.FileSystem
-
-
Uses of FileSystem in org.refcodes.filesystem
Classes in org.refcodes.filesystem that implement FileSystem Modifier and Type Class Description classChangeRootFileSystemWrapperImplThe change root space wrapper for a givenFileSystemrelocates the paths accessed by an application to the given namespace.classInMemoryFileSystemImplAn in-memoryFileSystemusing anConcurrentHashMapfor implementation.Methods in org.refcodes.filesystem that return FileSystem Modifier and Type Method Description FileSystemFileSystemAccessor. getFileSystem()Gets the file system stored by this property.Methods in org.refcodes.filesystem with parameters of type FileSystem Modifier and Type Method Description static voidFileSystemUtility. deleteFiles(FileSystem aFileSystem, java.lang.String aPath, boolean isRecursively)Deletes the entries found for the given path.voidFileSystemAccessor.FileSystemMutator. setFileSystem(FileSystem aFileSystem)Sets the file system for this property.static FileHandleFileSystemUtility. toNormalizedFileHandle(FileHandle aFileHandle, FileSystem aFileSystem)Test whether the given key may jail break from the name space.static java.lang.StringFileSystemUtility. toNormalizedKey(java.lang.String aKey, FileSystem aFileSystem)Truncates any prefixed path separator as we assemble our new path with the according namespace in front.static java.lang.StringFileSystemUtility. toNormalizedName(java.lang.String aName, FileSystem aFileSystem)Truncates any prefixed path separator as we assemble our new path with the according namespace in front.static java.lang.StringFileSystemUtility. toNormalizedPath(java.lang.String aPath, FileSystem aFileSystem)Truncates any prefixed path separator as we assemble our new path with the according namespace in front.Constructors in org.refcodes.filesystem with parameters of type FileSystem Constructor Description ChangeRootFileSystemWrapperImpl(java.lang.String aNamespace, FileSystem aFileSystem)Instantiates a new change root file system wrapper impl.
-