Interface FileHandle.MutableFileHandle
- All Superinterfaces:
CreatedDateAccessor, CreatedDateAccessor.CreatedDateMutator, CreatedDateAccessor.CreatedDateProperty, FileHandle, FileSizeAccessor, FileSizeAccessor.FileSizeMutator, FileSizeAccessor.FileSizeProperty, ModifiedDateAccessor, ModifiedDateAccessor.ModifiedDateMutator, ModifiedDateAccessor.ModifiedDateProperty, NameAccessor, NameAccessor.NameMutator, NameAccessor.NameProperty, PathAccessor<String>, PathAccessor.PathMutator<String>, PathAccessor.PathProperty<String>
- All Known Implementing Classes:
FileHandleImpl.MutableFileHandleImpl
- Enclosing interface:
FileHandle
public static interface FileHandle.MutableFileHandle
extends FileHandle, PathAccessor.PathProperty<String>, NameAccessor.NameProperty, FileSizeAccessor.FileSizeProperty, CreatedDateAccessor.CreatedDateProperty, ModifiedDateAccessor.ModifiedDateProperty
The mutable
FileHandle allows the modification of (fiddling
around with) attributes.
-------------------------------------------------------------------------
ATTENTION: Usually fiddling around with attributes is not necessary, as
the FileSystem itself provides the sufficient functionality to
work with files. In some cases though this might be necessary: This class
is being provided to allow modification of file attributes while making
sure that the FileHandle itself creates a copy so that any
additional attributes provided by extensions of this interface of whom
the developer does not know (yet) are preserved. So extensions of the
FileHandle know how to create a FileHandle.MutableFileHandle without
information loss, the business logic does not require to take care of any
yet unknown extensions.
-------------------------------------------------------------------------
CAUTION: Working with modified FileHandles on the
FileSystem can aCause unexpected (severe) behavior (data loss),
so we assume that you know what you do when using the
FileHandle.MutableFileHandle!-
Nested Class Summary
Nested classes/interfaces inherited from interface CreatedDateAccessor
CreatedDateAccessor.CreatedDateMutator, CreatedDateAccessor.CreatedDatePropertyNested classes/interfaces inherited from interface FileHandle
FileHandle.MutableFileHandleNested classes/interfaces inherited from interface FileSizeAccessor
FileSizeAccessor.FileSizeBuilder<B>, FileSizeAccessor.FileSizeMutator, FileSizeAccessor.FileSizePropertyNested classes/interfaces inherited from interface ModifiedDateAccessor
ModifiedDateAccessor.ModifiedDateMutator, ModifiedDateAccessor.ModifiedDatePropertyNested classes/interfaces inherited from interface NameAccessor
NameAccessor.NameBuilder<B>, NameAccessor.NameMutator, NameAccessor.NamePropertyNested classes/interfaces inherited from interface PathAccessor
PathAccessor.PathBuilder<T,B>, PathAccessor.PathMutator<T>, PathAccessor.PathProperty<T> -
Method Summary
Modifier and TypeMethodDescriptionConverts theFileHandle.MutableFileHandleback to aFileHandleto avoid hassle with collections, theObject.hashCode()and theObject.equals(Object)operations.Methods inherited from interface CreatedDateAccessor.CreatedDateMutator
setCreatedDateMethods inherited from interface CreatedDateAccessor.CreatedDateProperty
letCreatedDateMethods inherited from interface FileHandle
getCreatedDate, getFileSize, getModifiedDate, getName, getPath, toKey, toMutableFileHandleMethods inherited from interface FileSizeAccessor.FileSizeMutator
setFileSizeMethods inherited from interface FileSizeAccessor.FileSizeProperty
letFileSizeMethods inherited from interface ModifiedDateAccessor.ModifiedDateMutator
setModifiedDateMethods inherited from interface ModifiedDateAccessor.ModifiedDateProperty
letModifiedDateMethods inherited from interface NameAccessor.NameMutator
setNameMethods inherited from interface NameAccessor.NameProperty
letNameMethods inherited from interface PathAccessor.PathMutator
setPathMethods inherited from interface PathAccessor.PathProperty
letPath
-
Method Details
-
toFileHandle
FileHandle toFileHandle()Converts theFileHandle.MutableFileHandleback to aFileHandleto avoid hassle with collections, theObject.hashCode()and theObject.equals(Object)operations.- Returns:
- An immutable
FileHandlefrom thisFileHandle.MutableFileHandle.
-