-
- All Known Subinterfaces:
FileHandleAccessor.FileHandleProperty
- All Known Implementing Classes:
ConcurrentAccessException,IllegalFileHandleException,NoDeleteAccessException,NoReadAccessException,NoWriteAccessException,UnknownFileException
public interface FileHandleAccessorProvides an accessor for a file handle property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceFileHandleAccessor.FileHandleMutatorProvides a mutator for a file handle property.static interfaceFileHandleAccessor.FileHandlePropertyProvides a file handle property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description FileHandlegetFile()Retrieves the file handle from the file property.
-
-
-
Method Detail
-
getFile
FileHandle getFile()
Retrieves the file handle from the file property.- Returns:
- The file handle stored by the file handle property.
-
-