Class FileHandleImpl.MutableFileHandleImpl
java.lang.Object
org.refcodes.filesystem.FileHandleImpl
org.refcodes.filesystem.FileHandleImpl.MutableFileHandleImpl
- All Implemented Interfaces:
FileHandle,FileHandle.MutableFileHandle,FileSizeAccessor,FileSizeAccessor.FileSizeMutator,FileSizeAccessor.FileSizeProperty,org.refcodes.mixin.CreatedDateAccessor,org.refcodes.mixin.CreatedDateAccessor.CreatedDateMutator,org.refcodes.mixin.CreatedDateAccessor.CreatedDateProperty,org.refcodes.mixin.ModifiedDateAccessor,org.refcodes.mixin.ModifiedDateAccessor.ModifiedDateMutator,org.refcodes.mixin.ModifiedDateAccessor.ModifiedDateProperty,org.refcodes.mixin.NameAccessor,org.refcodes.mixin.NameAccessor.NameMutator,org.refcodes.mixin.NameAccessor.NameProperty,org.refcodes.mixin.PathAccessor,org.refcodes.mixin.PathAccessor.PathMutator,org.refcodes.mixin.PathAccessor.PathProperty
- Enclosing class:
FileHandleImpl
public class FileHandleImpl.MutableFileHandleImpl
extends FileHandleImpl
implements FileHandle.MutableFileHandle
The implementation of a
FileHandle.MutableFileHandle.
-------------------------------------------------------------------------
CAUTION: fiddling with the path and the name attributes causes the
hashCode() and equals(Object) methods to change
behavior which can aCause problems ehttps://www.metacodes.proly in
collections!
-------------------------------------------------------------------------
ATTENTION: In order to avoid the above mentioned problems with the
equals(Object) and hashCode() methods, use
toFileHandle() before storing a FileHandle.MutableFileHandle in a
collection.-
Nested Class Summary
Nested classes/interfaces inherited from class org.refcodes.filesystem.FileHandleImpl
FileHandleImpl.MutableFileHandleImplNested classes/interfaces inherited from interface org.refcodes.mixin.CreatedDateAccessor
org.refcodes.mixin.CreatedDateAccessor.CreatedDateMutator, org.refcodes.mixin.CreatedDateAccessor.CreatedDatePropertyNested classes/interfaces inherited from interface org.refcodes.filesystem.FileHandle
FileHandle.MutableFileHandleNested classes/interfaces inherited from interface org.refcodes.filesystem.FileSizeAccessor
FileSizeAccessor.FileSizeBuilder<B extends FileSizeAccessor.FileSizeBuilder<B>>, FileSizeAccessor.FileSizeMutator, FileSizeAccessor.FileSizePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.ModifiedDateAccessor
org.refcodes.mixin.ModifiedDateAccessor.ModifiedDateMutator, org.refcodes.mixin.ModifiedDateAccessor.ModifiedDatePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.NameAccessor
org.refcodes.mixin.NameAccessor.NameBuilder<B extends org.refcodes.mixin.NameAccessor.NameBuilder<B>>, org.refcodes.mixin.NameAccessor.NameMutator, org.refcodes.mixin.NameAccessor.NamePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.PathAccessor
org.refcodes.mixin.PathAccessor.PathBuilder<B extends org.refcodes.mixin.PathAccessor.PathBuilder<?>>, org.refcodes.mixin.PathAccessor.PathMutator, org.refcodes.mixin.PathAccessor.PathProperty -
Field Summary
Fields inherited from class org.refcodes.filesystem.FileHandleImpl
_createdDate, _modifiedDate, _name, _path, _size -
Constructor Summary
ConstructorsConstructorDescriptionMutableFileHandleImpl(String aPath, String aName, long aSize, Date aCreatedDate, Date aModifiedDate) Instantiates a new mutable file handle impl.MutableFileHandleImpl(FileHandle aFileHandle) Instantiates a new mutable file handle impl. -
Method Summary
Modifier and TypeMethodDescriptionbooleaninthashCode()voidsetCreatedDate(Date aCreatedDate) voidsetFileSize(long aSize) Sets the size for the size property.voidsetModifiedDate(Date aModifiedDate) voidvoidConverts theFileHandle.MutableFileHandleback to aFileHandleto avoid hassle with collections, theObject.hashCode()and theObject.equals(Object)operations.Methods inherited from class org.refcodes.filesystem.FileHandleImpl
getCreatedDate, getFileSize, getModifiedDate, getName, getPath, toKey, toMutableFileHandleMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.refcodes.mixin.CreatedDateAccessor.CreatedDateProperty
letCreatedDateMethods inherited from interface org.refcodes.filesystem.FileHandle
getCreatedDate, getFileSize, getModifiedDate, getName, getPath, toKey, toMutableFileHandleMethods inherited from interface org.refcodes.filesystem.FileSizeAccessor.FileSizeProperty
letFileSizeMethods inherited from interface org.refcodes.mixin.ModifiedDateAccessor.ModifiedDateProperty
letModifiedDateMethods inherited from interface org.refcodes.mixin.NameAccessor.NameProperty
letNameMethods inherited from interface org.refcodes.mixin.PathAccessor.PathProperty
letPath
-
Constructor Details
-
MutableFileHandleImpl
-
MutableFileHandleImpl
Instantiates a new mutable file handle impl.- Parameters:
aFileHandle- the file handle
-
-
Method Details
-
setModifiedDate
- Specified by:
setModifiedDatein interfaceorg.refcodes.mixin.ModifiedDateAccessor.ModifiedDateMutator
-
setFileSize
public void setFileSize(long aSize) Sets the size for the size property.- Specified by:
setFileSizein interfaceFileSizeAccessor.FileSizeMutator- Parameters:
aSize- The size to be stored by the size property.
-
setName
- Specified by:
setNamein interfaceorg.refcodes.mixin.NameAccessor.NameMutator
-
setPath
- Specified by:
setPathin interfaceorg.refcodes.mixin.PathAccessor.PathMutator
-
setCreatedDate
- Specified by:
setCreatedDatein interfaceorg.refcodes.mixin.CreatedDateAccessor.CreatedDateMutator
-
hashCode
public int hashCode()- Overrides:
hashCodein classFileHandleImpl
-
equals
- Overrides:
equalsin classFileHandleImpl
-
toFileHandle
Converts theFileHandle.MutableFileHandleback to aFileHandleto avoid hassle with collections, theObject.hashCode()and theObject.equals(Object)operations.- Specified by:
toFileHandlein interfaceFileHandle.MutableFileHandle- Returns:
- An immutable
FileHandlefrom thisFileHandle.MutableFileHandle.
-