Module org.refcodes.filesystem
Package org.refcodes.filesystem
Class FileHandleImpl.MutableFileHandleImpl
- java.lang.Object
-
- org.refcodes.filesystem.FileHandleImpl
-
- org.refcodes.filesystem.FileHandleImpl.MutableFileHandleImpl
-
- All Implemented Interfaces:
FileHandle,FileHandle.MutableFileHandle,FileSizeAccessor,FileSizeAccessor.FileSizeMutator,FileSizeAccessor.FileSizeProperty,org.refcodes.mixin.CreatedDateAccessor,org.refcodes.mixin.CreatedDateAccessor.CreatedDateMutator,org.refcodes.mixin.CreatedDateAccessor.CreatedDateProperty,org.refcodes.mixin.ModifiedDateAccessor,org.refcodes.mixin.ModifiedDateAccessor.ModifiedDateMutator,org.refcodes.mixin.ModifiedDateAccessor.ModifiedDateProperty,org.refcodes.mixin.NameAccessor,org.refcodes.mixin.NameAccessor.NameMutator,org.refcodes.mixin.NameAccessor.NameProperty,org.refcodes.mixin.PathAccessor,org.refcodes.mixin.PathAccessor.PathMutator,org.refcodes.mixin.PathAccessor.PathProperty
- Enclosing class:
- FileHandleImpl
public class FileHandleImpl.MutableFileHandleImpl extends FileHandleImpl implements FileHandle.MutableFileHandle
The implementation of aFileHandle.MutableFileHandle. ------------------------------------------------------------------------- CAUTION: fiddling with the path and the name attributes causes thehashCode()andequals(Object)methods to change behavior which can cause problems especially in collections! ------------------------------------------------------------------------- ATTENTION: In order to avoid the above mentioned problems with theequals(Object)andhashCode()methods, usetoFileHandle()before storing aFileHandle.MutableFileHandlein a collection.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from class org.refcodes.filesystem.FileHandleImpl
FileHandleImpl.MutableFileHandleImpl
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.CreatedDateAccessor
org.refcodes.mixin.CreatedDateAccessor.CreatedDateMutator, org.refcodes.mixin.CreatedDateAccessor.CreatedDateProperty
-
Nested classes/interfaces inherited from interface org.refcodes.filesystem.FileHandle
FileHandle.MutableFileHandle
-
Nested classes/interfaces inherited from interface org.refcodes.filesystem.FileSizeAccessor
FileSizeAccessor.FileSizeMutator, FileSizeAccessor.FileSizeProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.ModifiedDateAccessor
org.refcodes.mixin.ModifiedDateAccessor.ModifiedDateMutator, org.refcodes.mixin.ModifiedDateAccessor.ModifiedDateProperty
-
-
Field Summary
-
Fields inherited from class org.refcodes.filesystem.FileHandleImpl
_createdDate, _modifiedDate, _name, _path, _size
-
-
Constructor Summary
Constructors Constructor Description MutableFileHandleImpl(String aPath, String aName, long aSize, Date aCreatedDate, Date aModifiedDate)Instantiates a new mutable file handle impl.MutableFileHandleImpl(FileHandle aFileHandle)Instantiates a new mutable file handle impl.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object obj)inthashCode()voidsetCreatedDate(Date aCreatedDate)voidsetFileSize(long aSize)Sets the size for the size property.voidsetModifiedDate(Date aModifiedDate)voidsetName(String aName)voidsetPath(String aPath)FileHandletoFileHandle()Converts theFileHandle.MutableFileHandleback to aFileHandleto avoid hassle with collections, theObject.hashCode()and theObject.equals(Object)operations.-
Methods inherited from class org.refcodes.filesystem.FileHandleImpl
getCreatedDate, getFileSize, getModifiedDate, getName, getPath, toKey, toMutableFileHandle
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, toString, wait, wait, wait
-
Methods inherited from interface org.refcodes.mixin.CreatedDateAccessor.CreatedDateProperty
letCreatedDate
-
Methods inherited from interface org.refcodes.filesystem.FileHandle
getCreatedDate, getFileSize, getModifiedDate, getName, getPath, toKey, toMutableFileHandle
-
Methods inherited from interface org.refcodes.filesystem.FileSizeAccessor.FileSizeProperty
letFileSize
-
-
-
-
Constructor Detail
-
MutableFileHandleImpl
public MutableFileHandleImpl(String aPath, String aName, long aSize, Date aCreatedDate, Date aModifiedDate)
Instantiates a new mutable file handle impl.- Parameters:
aPath- the pathaName- the nameaSize- the sizeaCreatedDate- the created dateaModifiedDate- the modified date
-
MutableFileHandleImpl
public MutableFileHandleImpl(FileHandle aFileHandle)
Instantiates a new mutable file handle impl.- Parameters:
aFileHandle- the file handle
-
-
Method Detail
-
setModifiedDate
public void setModifiedDate(Date aModifiedDate)
- Specified by:
setModifiedDatein interfaceorg.refcodes.mixin.ModifiedDateAccessor.ModifiedDateMutator
-
setFileSize
public void setFileSize(long aSize)
Sets the size for the size property.- Specified by:
setFileSizein interfaceFileSizeAccessor.FileSizeMutator- Parameters:
aSize- The size to be stored by the size property.
-
setName
public void setName(String aName)
- Specified by:
setNamein interfaceorg.refcodes.mixin.NameAccessor.NameMutator
-
setPath
public void setPath(String aPath)
- Specified by:
setPathin interfaceorg.refcodes.mixin.PathAccessor.PathMutator
-
setCreatedDate
public void setCreatedDate(Date aCreatedDate)
- Specified by:
setCreatedDatein interfaceorg.refcodes.mixin.CreatedDateAccessor.CreatedDateMutator
-
hashCode
public int hashCode()
- Overrides:
hashCodein classFileHandleImpl
-
equals
public boolean equals(Object obj)
- Overrides:
equalsin classFileHandleImpl
-
toFileHandle
public FileHandle toFileHandle()
Converts theFileHandle.MutableFileHandleback to aFileHandleto avoid hassle with collections, theObject.hashCode()and theObject.equals(Object)operations.- Specified by:
toFileHandlein interfaceFileHandle.MutableFileHandle- Returns:
- An immutable
FileHandlefrom thisFileHandle.MutableFileHandle.
-
-