Uses of Interface
org.refcodes.filesystem.FileHandle
-
Uses of FileHandle in org.refcodes.filesystem
Subinterfaces of FileHandle in org.refcodes.filesystemModifier and TypeInterfaceDescriptionstatic interfaceThe mutableFileHandleallows the modification of (fiddling around with) attributes. ------------------------------------------------------------------------- ATTENTION: Usually fiddling around with attributes is not necessary, as theFileSystemitself provides the sufficient functionality to work with files.Classes in org.refcodes.filesystem that implement FileHandleModifier and TypeClassDescriptionclassStraight forward implementation of theFileHandle,.classThe implementation of aFileHandle.MutableFileHandle. ------------------------------------------------------------------------- CAUTION: fiddling with the path and the name attributes causes theFileHandleImpl.MutableFileHandleImpl.hashCode()andFileHandleImpl.MutableFileHandleImpl.equals(Object)methods to change behavior which can cause problems ehttps://www.metacodes.proly in collections!Methods in org.refcodes.filesystem that return FileHandleModifier and TypeMethodDescriptionChangeRootFileSystemWrapperImpl.createFile(String aKey) Creates a file (handle) with the given key.ChangeRootFileSystemWrapperImpl.createFile(String aPath, String aName) Creates a file (handle) with the given path and name.FileSystem.createFile(String aKey) Creates a file (handle) with the given key.FileSystem.createFile(String aPath, String aName) Creates a file (handle) with the given path and name.InMemoryFileSystem.createFile(String aKey) Creates a file (handle) with the given key.InMemoryFileSystem.createFile(String aPath, String aName) Creates a file (handle) with the given path and name.FileHandleAccessor.getFile()Retrieves the file handle from the file property.ChangeRootFileSystemWrapperImpl.getFileHandle(String aKey) Gets a file (handle) with the given key from the file system.ChangeRootFileSystemWrapperImpl.getFileHandle(String aPath, String aName) Gets a file (handle) with the given path and name from the file system.FileSystem.getFileHandle(String aKey) Gets a file (handle) with the given key from the file system.FileSystem.getFileHandle(String aPath, String aName) Gets a file (handle) with the given path and name from the file system.InMemoryFileSystem.getFileHandle(String aKey) Gets a file (handle) with the given key from the file system.InMemoryFileSystem.getFileHandle(String aPath, String aName) Gets a file (handle) with the given path and name from the file system.default FileHandleThis method stores and passes through the given argument, which is very useful for builder APIs: Sets the given file handle (setter) as ofFileHandleAccessor.FileHandleMutator.setFile(String)and returns the very same value (getter) being produced to aFileHandle(as ofFileHandleAccessor.getFile()).ChangeRootFileSystemWrapperImpl.moveFile(FileHandle aFileHandle, String aNewKey) Renames the file (handle), it will be accessible via the provided key.FileSystem.moveFile(FileHandle aFileHandle, String aNewKey) Renames the file (handle), it will be accessible via the provided key.InMemoryFileSystem.moveFile(FileHandle aFileHandle, String aNewKey) Renames the file (handle), it will be accessible via the provided key.ChangeRootFileSystemWrapperImpl.renameFile(FileHandle aFileHandle, String aNewName) Renames the file (handle), the name part of the key will be renamed to the new name.FileSystem.renameFile(FileHandle aFileHandle, String aNewName) Renames the file (handle), the name part of the key will be renamed to the new name.InMemoryFileSystem.renameFile(FileHandle aFileHandle, String aNewName) Renames the file (handle), the name part of the key will be renamed to the new name.FileHandle.MutableFileHandle.toFileHandle()Converts theFileHandle.MutableFileHandleback to aFileHandleto avoid hassle with collections, theObject.hashCode()and theObject.equals(Object)operations.FileHandleImpl.MutableFileHandleImpl.toFileHandle()Converts theFileHandle.MutableFileHandleback to aFileHandleto avoid hassle with collections, theObject.hashCode()and theObject.equals(Object)operations.static FileHandleFileSystemUtility.toNormalizedFileHandle(FileHandle aFileHandle, FileSystem aFileSystem) Test whether the given key may jail break from the name space.Methods in org.refcodes.filesystem that return types with arguments of type FileHandleModifier and TypeMethodDescriptionChangeRootFileSystemWrapperImpl.getFileHandles(String aPath, boolean isRecursively) With the behavior of theFileSystem.hasFiles(String, boolean)method, all file (handle)s found for the path are returned.FileSystem.getFileHandles(String aPath, boolean isRecursively) With the behavior of theFileSystem.hasFiles(String, boolean)method, all file (handle)s found for the path are returned.InMemoryFileSystem.getFileHandles(String aPath, boolean isRecursively) With the behavior of theFileSystem.hasFiles(String, boolean)method, all file (handle)s found for the path are returned.Methods in org.refcodes.filesystem with parameters of type FileHandleModifier and TypeMethodDescriptionvoidChangeRootFileSystemWrapperImpl.deleteFile(FileHandle aFileHandle) Deletes a file (handle) from the file system.voidFileSystem.deleteFile(FileHandle aFileHandle) Deletes a file (handle) from the file system.voidInMemoryFileSystem.deleteFile(FileHandle aFileHandle) Deletes a file (handle) from the file system.ChangeRootFileSystemWrapperImpl.fromFile(FileHandle aFromFileHandle) An input stream is being provided from which the data of the file (handle) may be read.voidChangeRootFileSystemWrapperImpl.fromFile(FileHandle aFromFileHandle, File aToFile) The data contained in the given file (handle) is written to the provided file.voidChangeRootFileSystemWrapperImpl.fromFile(FileHandle aFromFileHandle, OutputStream aOutputStream) The data contained in the given file (handle) is written to the provided output stream.FileSystem.fromFile(FileHandle aFromFileHandle) An input stream is being provided from which the data of the file (handle) may be read.voidFileSystem.fromFile(FileHandle aFromFileHandle, File aToFile) The data contained in the given file (handle) is written to the provided file.voidFileSystem.fromFile(FileHandle aFromFileHandle, OutputStream aOutputStream) The data contained in the given file (handle) is written to the provided output stream.InMemoryFileSystem.fromFile(FileHandle aFromFileHandle) An input stream is being provided from which the data of the file (handle) may be read.voidInMemoryFileSystem.fromFile(FileHandle aFromFileHandle, File aToFile) The data contained in the given file (handle) is written to the provided file.voidInMemoryFileSystem.fromFile(FileHandle aFromFileHandle, OutputStream aOutputStream) The data contained in the given file (handle) is written to the provided output stream.booleanChangeRootFileSystemWrapperImpl.hasFile(FileHandle aFileHandle) Returns true in case the given file (handle) exists.booleanFileSystem.hasFile(FileHandle aFileHandle) Returns true in case the given file (handle) exists.booleanInMemoryFileSystem.hasFile(FileHandle aFileHandle) Returns true in case the given file (handle) exists.ChangeRootFileSystemWrapperImpl.moveFile(FileHandle aFileHandle, String aNewKey) Renames the file (handle), it will be accessible via the provided key.FileSystem.moveFile(FileHandle aFileHandle, String aNewKey) Renames the file (handle), it will be accessible via the provided key.InMemoryFileSystem.moveFile(FileHandle aFileHandle, String aNewKey) Renames the file (handle), it will be accessible via the provided key.ChangeRootFileSystemWrapperImpl.renameFile(FileHandle aFileHandle, String aNewName) Renames the file (handle), the name part of the key will be renamed to the new name.FileSystem.renameFile(FileHandle aFileHandle, String aNewName) Renames the file (handle), the name part of the key will be renamed to the new name.InMemoryFileSystem.renameFile(FileHandle aFileHandle, String aNewName) Renames the file (handle), the name part of the key will be renamed to the new name.ChangeRootFileSystemWrapperImpl.toFile(FileHandle aToFileHandle) Returns an output stream which may be used to write (or append, in case data did already exist for the file system) data to a file (handle).voidChangeRootFileSystemWrapperImpl.toFile(FileHandle aToFileHandle, byte[] aBuffer) Data provided by the given buffer is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).voidChangeRootFileSystemWrapperImpl.toFile(FileHandle aToFileHandle, File aFromFile) Data provided by the given input stream is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).voidChangeRootFileSystemWrapperImpl.toFile(FileHandle aToFileHandle, InputStream aInputStream) Data provided by the given input stream is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).FileSystem.toFile(FileHandle aToFileHandle) Returns an output stream which may be used to write (or append, in case data did already exist for the file system) data to a file (handle).voidFileSystem.toFile(FileHandle aToFileHandle, byte[] aBuffer) Data provided by the given buffer is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).voidFileSystem.toFile(FileHandle aToFileHandle, File aFromFile) Data provided by the given input stream is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).voidFileSystem.toFile(FileHandle aToFileHandle, InputStream aInputStream) Data provided by the given input stream is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).InMemoryFileSystem.toFile(FileHandle aToFileHandle) Returns an output stream which may be used to write (or append, in case data did already exist for the file system) data to a file (handle).voidInMemoryFileSystem.toFile(FileHandle aToFileHandle, byte[] aBuffer) Data provided by the given buffer is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).voidInMemoryFileSystem.toFile(FileHandle aToFileHandle, File aFromFile) Data provided by the given input stream is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).voidInMemoryFileSystem.toFile(FileHandle aToFileHandle, InputStream aInputStream) Data provided by the given input stream is written to the file (handle) (or appended to the file (handle)'s data in case the file (handle) did already contain data).static FileHandleFileSystemUtility.toNormalizedFileHandle(FileHandle aFileHandle, FileSystem aFileSystem) Test whether the given key may jail break from the name space.Constructors in org.refcodes.filesystem with parameters of type FileHandleModifierConstructorDescriptionConcurrentAccessException(FileHandle aFile, String message) Instantiates a new concurrent access exception.ConcurrentAccessException(FileHandle aFile, String aMessage, String aErrorCode) Instantiates a new concurrent access exception.ConcurrentAccessException(FileHandle aFile, String message, Throwable cause) Instantiates a new concurrent access exception.ConcurrentAccessException(FileHandle aFile, String aMessage, Throwable aCause, String aErrorCode) Instantiates a new concurrent access exception.ConcurrentAccessException(FileHandle aFile, Throwable cause) Instantiates a new concurrent access exception.ConcurrentAccessException(FileHandle aFile, Throwable aCause, String aErrorCode) Instantiates a new concurrent access exception.FileHandleImpl(FileHandle aFileHandle) Constructs aFileHandleobject with the properties of the givenFileHandle.IllegalFileHandleException(FileHandle aFile, String message) Instantiates a new illegal file handle exception.IllegalFileHandleException(FileHandle aFile, String aMessage, String aErrorCode) Instantiates a new illegal file handle exception.IllegalFileHandleException(FileHandle aFile, String message, Throwable cause) Instantiates a new illegal file handle exception.IllegalFileHandleException(FileHandle aFile, String aMessage, Throwable aCause, String aErrorCode) Instantiates a new illegal file handle exception.IllegalFileHandleException(FileHandle aFile, Throwable cause) Instantiates a new illegal file handle exception.IllegalFileHandleException(FileHandle aFile, Throwable aCause, String aErrorCode) Instantiates a new illegal file handle exception.MutableFileHandleImpl(FileHandle aFileHandle) Instantiates a new mutable file handle impl.NoDeleteAccessException(FileHandle aFile, String message) Instantiates a new no delete access exception.NoDeleteAccessException(FileHandle aFile, String aMessage, String aErrorCode) Instantiates a new no delete access exception.NoDeleteAccessException(FileHandle aFile, String message, Throwable cause) Instantiates a new no delete access exception.NoDeleteAccessException(FileHandle aFile, String aMessage, Throwable aCause, String aErrorCode) Instantiates a new no delete access exception.NoDeleteAccessException(FileHandle aFile, Throwable cause) Instantiates a new no delete access exception.NoDeleteAccessException(FileHandle aFile, Throwable aCause, String aErrorCode) Instantiates a new no delete access exception.NoReadAccessException(FileHandle aFile, String message) Instantiates a new no read access exception.NoReadAccessException(FileHandle aFile, String aMessage, String aErrorCode) Instantiates a new no read access exception.NoReadAccessException(FileHandle aFile, String message, Throwable cause) Instantiates a new no read access exception.NoReadAccessException(FileHandle aFile, String aMessage, Throwable aCause, String aErrorCode) Instantiates a new no read access exception.NoReadAccessException(FileHandle aFile, Throwable cause) Instantiates a new no read access exception.NoReadAccessException(FileHandle aFile, Throwable aCause, String aErrorCode) Instantiates a new no read access exception.NoWriteAccessException(FileHandle aFile, String message) Instantiates a new no write access exception.NoWriteAccessException(FileHandle aFile, String aMessage, String aErrorCode) Instantiates a new no write access exception.NoWriteAccessException(FileHandle aFile, String message, Throwable cause) Instantiates a new no write access exception.NoWriteAccessException(FileHandle aFile, String aMessage, Throwable aCause, String aErrorCode) Instantiates a new no write access exception.NoWriteAccessException(FileHandle aFile, Throwable cause) Instantiates a new no write access exception.NoWriteAccessException(FileHandle aFile, Throwable aCause, String aErrorCode) Instantiates a new no write access exception.UnknownFileException(FileHandle aFile, String message) Instantiates a new unknown file exception.UnknownFileException(FileHandle aFile, String aMessage, String aErrorCode) Instantiates a new unknown file exception.UnknownFileException(FileHandle aFile, String message, Throwable cause) Instantiates a new unknown file exception.UnknownFileException(FileHandle aFile, String aMessage, Throwable aCause, String aErrorCode) Instantiates a new unknown file exception.UnknownFileException(FileHandle aFile, Throwable cause) Instantiates a new unknown file exception.UnknownFileException(FileHandle aFile, Throwable aCause, String aErrorCode) Instantiates a new unknown file exception.